# anomalearn: time series anomaly detection library

## When will the code be fully released?

ASAP since it is part of a thesis work whose dissertation is planned
for 4th May 2023.

## Current state of the package

Because of how thesis' submission is handled, the name of the library must be
"registered" in some way before thesis submission in university's online
services.

## What is it?

anomalearn is a [**Python**][python-url] package that provides modular and
extensible functionalities for developing anomaly detection methods for time
series data, reading publicly available time series anomaly detection datasets,
creating the loading of data for experiments, and dataset evaluation functions.
Additionally, anomalearn development's plans include the implementation of
several state-of-the-art and historical anomaly detection methods, and the
implementation of objects to automate the training process of methods. See
Discussion and development section for more details.

[python-url]: https://www.python.org/